@@ -23,12 +23,6 @@
 #include <gtk/gtkwidget.h>
 #include <gnome.h>
 
-enum {
-	GCONF_EDITOR_WINDOW_NORMAL,
-	GCONF_EDITOR_WINDOW_DEFAULTS,
-	GCONF_EDITOR_WINDOW_MANDATORY
-};
-
 GtkWidget *gconf_editor_application_create_editor_window (int type);
 
 #endif /* __GCONF_EDITOR_APPLICATION_H__ */
